@@ -524,7 +524,7 @@ class FreeWili:
 
     def read_i2c(
         self, address: int, register: int, data_size: int, processor: FreeWiliProcessorType = FreeWiliProcessorType.Main
-    ) -> Result[ResponseFrame, str]:
+    ) -> Result[bytes, str]:
         """Write I2C data.
 
         Parameters:
@@ -553,7 +553,7 @@ class FreeWili:
 
     def write_i2c(
         self, address: int, register: int, data: bytes, processor: FreeWiliProcessorType = FreeWiliProcessorType.Main
-    ) -> Result[ResponseFrame, str]:
+    ) -> Result[str, str]:
         """Write I2C data.
 
         Parameters:
@@ -569,8 +569,9 @@ class FreeWili:
 
         Returns:
         -------
-            Result[ResponseFrame, str]:
-                Ok(ResponseFrame) if the command was sent successfully, Err(str) if not.
+            Result[str, str]:
+                Ok(str) if the command was sent successfully, Err(str) if not.
+                The str is the response from the device, typically "OK".
         """
         match self.get_serial_from(processor):
             case Ok(serial):
@@ -580,8 +581,8 @@ class FreeWili:
             case _:
                 raise RuntimeError("Missing case statement")
 
-    def poll_i2c(self, processor: FreeWiliProcessorType = FreeWiliProcessorType.Main) -> Result[ResponseFrame, str]:
-        """Write I2C data.
+    def poll_i2c(self, processor: FreeWiliProcessorType = FreeWiliProcessorType.Main) -> Result[tuple[int, ...], str]:
+        """Poll I2C data.
 
         Parameters:
         ----------
@@ -590,8 +591,8 @@ class FreeWili:
 
         Returns:
         -------
-            Result[ResponseFrame, str]:
-                Ok(ResponseFrame) if the command was sent successfully, Err(str) if not.
+            Result[tuple[int, ...], str]:
+                Ok(tuple[int, ...]) if the command was sent successfully, Err(str) if not.
         """
         match self.get_serial_from(processor):
             case Ok(serial):
